# Lux_Proposal Repository 

This is a location for code under development for the Lux mission concept. Currently it contains a simple exposure time calculator.

Dependencies: numpy, pandas, astropy, matplotlib, specutils

The current version (0.1.0) contains representations of the 3 channels of the Lux instrument (UV, Optical, NIR), as well as performance estimates for both imaging and spectroscopy modes. <b>The performance estimates are calculated using both requirements level parameters, as well as current best estimates. Unless you know what you are doing, please use the requirements-level performance estimates (default behavior).</b>

Installation: pip install luxetc

For usage examples, please the associated jupyter notebooks (LuxETC-ImagingDemo.ipynb and LuxETC-SpectroscopyDemo.ipynb).

Questions? <br>
Brad Cenko (brad.cenko@nasa.gov) <br>
Dave Sand (dsand@arizona.edu) <br>
